@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -251,53 +251,55 @@
 
 			setUp: function( editor, definition ) {
 				editor.on( 'paste', function( evt ) {
-					var method = evt.data.method,
-						dataTransfer = evt.data.dataTransfer,
+					var dataTransfer = evt.data.dataTransfer,
+						isFileTransfer = dataTransfer && dataTransfer.isFileTransfer(),
 						filesCount = dataTransfer && dataTransfer.getFilesCount();
 
-					if ( editor.readOnly ) {
+					if ( editor.readOnly || !isFileTransfer ) {
 						return;
 					}
 
-					if ( method === 'drop' || ( method === 'paste' && filesCount ) ) {
-						var matchedFiles = [],
-							curFile;
+					var matchedFiles = [],
+						curFile;
 
-						// Refetch the definition... original definition looks like an outdated copy and it doesn't
-						// include members inherited from imagebase.
-						definition = editor.widgets.registered[ definition.name ];
+					// Refetch the definition... original definition looks like an outdated copy and it doesn't
+					// include members inherited from imagebase.
+					definition = editor.widgets.registered[ definition.name ];
 
-						for ( var i = 0; i < filesCount; i++ ) {
-							curFile = dataTransfer.getFile( i );
+					for ( var i = 0; i < filesCount; i++ ) {
+						curFile = dataTransfer.getFile( i );
 
-							if ( CKEDITOR.fileTools.isTypeSupported( curFile, definition.supportedTypes ) ) {
-								matchedFiles.push( curFile );
-							}
-						}
-
-						if ( matchedFiles.length ) {
-							evt.cancel();
-							// At the time being we expect no other actions to happen after the widget was inserted.
-							evt.stop();
-
-							CKEDITOR.tools.array.forEach( matchedFiles, function( curFile, index ) {
-								var loader = ret._spawnLoader( editor, curFile, definition, curFile.name );
-
-								ret._insertWidget( editor, definition, URL.createObjectURL( curFile ), true, { uploadId: loader.id } );
-
-								// Now modify the selection so that the next widget won't replace the current one.
-								// This selection workaround is required to store multiple files.
-								if ( index !== matchedFiles.length - 1 ) {
-									// We don't want to modify selection for the last element, so that the last widget remains selected.
-									var sel = editor.getSelection(),
-										ranges = sel.getRanges();
-
-									ranges[ 0 ].enlarge( CKEDITOR.ENLARGE_ELEMENT );
-									ranges[ 0 ].collapse( false );
-								}
-							} );
+						if ( CKEDITOR.fileTools.isTypeSupported( curFile, definition.supportedTypes ) ) {
+							matchedFiles.push( curFile );
 						}
 					}
+
+					if ( matchedFiles.length === 0 ) {
+						return;
+					}
+
+					evt.cancel();
+					// At the time being we expect no other actions to happen after the widget was inserted.
+					evt.stop();
+
+					CKEDITOR.tools.array.forEach( matchedFiles, function( curFile, index ) {
+						var loader = ret._spawnLoader( editor, curFile, definition, curFile.name );
+
+						ret._insertWidget( editor, definition, URL.createObjectURL( curFile ), true, { uploadId: loader.id } );
+
+						// Now modify the selection so that the next widget won't replace the current one.
+						// This selection workaround is required to store multiple files.
+						if ( index === matchedFiles.length - 1 ) {
+							// We don't want to modify selection for the last element, so that the last widget remains selected.
+							return;
+						}
+
+						var sel = editor.getSelection(),
+							ranges = sel.getRanges();
+
+						ranges[ 0 ].enlarge( CKEDITOR.ENLARGE_ELEMENT );
+						ranges[ 0 ].collapse( false );
+					} );
 				} );
 			},
 
@@ -841,7 +843,7 @@
 
 	CKEDITOR.plugins.add( 'imagebase', {
 		requires: 'widget,filetools',
-		lang: 'az,bg,cs,da,de,en,en-au,et,fa,fr,gl,hr,hu,it,ku,lt,lv,nb,nl,pl,pt,pt-br,ro,ru,sk,sq,sr,sr-latn,sv,tr,ug,uk,zh,zh-cn',
+		lang: 'az,bg,cs,da,de,de-ch,el,en,en-au,et,fa,fr,gl,hr,hu,it,ku,lt,lv,nb,nl,pl,pt,pt-br,ro,ru,sk,sq,sr,sr-latn,sv,tr,ug,uk,zh,zh-cn',
 
 		init: function( editor ) {
 			loadStyles( editor, this );
