@@ -1,6 +1,6 @@
 /* bender-tags: editor */
 // jscs:disable maximumLineLength
-/* bender-ckeditor-plugins: about,basicstyles,bidi,blockquote,clipboard,colorbutton,colordialog,div,enterkey,entities,find,flash,font,format,forms,horizontalrule,image,iframe,indent,justify,link,list,newpage,pagebreak,pastefromword,pastetext,removeformat,resize,toolbar,save,selectall,showblocks,showborders,smiley,sourcearea,specialchar,stylescombo,table,templates,undo,wysiwygarea */
+/* bender-ckeditor-plugins: about,basicstyles,bidi,blockquote,clipboard,colorbutton,colordialog,div,enterkey,entities,find,font,format,forms,horizontalrule,image,iframe,indent,justify,link,list,newpage,pagebreak,pastefromword,pastetext,removeformat,resize,toolbar,save,selectall,showblocks,showborders,smiley,sourcearea,specialchar,stylescombo,table,templates,undo,wysiwygarea */
 // jscs:enable maximumLineLength
 
 var doc = CKEDITOR.document;
@@ -22,6 +22,11 @@ bender.test( {
 		} );
 	},
 
+	// (#4918)
+	test_startup_computed_state_value: function() {
+		assert.isTrue( this.editor.config.useComputedState, 'config.useComputedState should return true as default' );
+	},
+
 	test_startup_focus: function() {
 		assert.isTrue( this.editor.focusManager.hasFocus, 'config.startupFocus' );
 	},
